# -*- coding: utf-8 -*-

import sys

_manager = None


def get_emblem_manager():
    global _manager

    if _manager is not None:
        return _manager

    if sys.platform == 'win32':
        from .windows.win32_emblem import Win32ComOverlayHandlerServer
        _manager = Win32ComOverlayHandlerServer()
    elif sys.platform.startswith('linux'):
        from .linux.gio_emblem import GIOBasedEmblemManagement
        _manager = GIOBasedEmblemManagement()
    else:
        # dummy manager, it does nothing.
        from .abstract_emblem import AbstractEmblemManagement
        _manager = AbstractEmblemManagement()

    return _manager


# TODO this method must be called at the bajoo installation
#   and at the end of the installation, the users should restart the computer
def install_emblem():
    if sys.platform == 'win32':
        from .windows import install_com_server, is_installed

        if not is_installed():
            install_com_server()


# TODO this method must be called at the bajoo uninstallation
#   and at the end of the uninstallation, the users should restart the computer
def uninstall_emblem():
    if sys.platform == 'win32':
        from .windows import uninstall_com_server, is_installed

        if is_installed():
            uninstall_com_server()
