# -*- coding: utf-8 -*-

# About gio, this current script uses the deprecated way to use it, because
# it does not work with the new import style.  The emblem attribute to set
# on a file is supposed to be an array, and the new import style wrapper
# does not support the array argument passing from python to C++.
# Everywhere in this code are present comment prefixed with 'NEWSTYLE',
# it is the code supposed to be the way to use the new import style.

import errno
import gio
# NEWSTYLE from gi.repository import Gio
import os
from time import time

from ..abstract_emblem import AbstractEmblemManagement

# default emblem for gnome
# /usr/share/icons/hicolor/24x24/emblems/
# TODO use bajoo emblem when they will be ready

# EMBLEM_FAVORITE = "folder_emblem_favorite"
EMBLEM_FINISHED = "folder_emblem_finished"
# EMBLEM_IMPORTANT = "folder_emblem_important"  # could be used for error state
EMBLEM_IN_PROGRESS = "folder_emblem_in_progress"

# The emblem constants only contains the filename without the path and
# without the extension.  The file explorer will automaticaly retrieve
# the size, the type and the thema, then it will build the path.


class GIOBasedEmblemManagement(AbstractEmblemManagement):
    def __init__(self):
        AbstractEmblemManagement.__init__(self)
        self.files = {}

    def _touch(self, path):
        """
            this method updates the file access time and keep the last
            modified time.

            It does nothing if the path does not exist.

            It is equivalent to the following command:
                touch -a -c FILE_PATH
        """
        try:
            stinfo = os.stat(path)
            os.utime(path, (time(), stinfo.st_mtime,))
        except OSError as ose:
            if ose.errno is not errno.ENOENT:
                raise

    def _get_gio_file(self, file_path):
        if file_path in self.files:
            return self.files[file_path]
        else:
            gio_file = gio.File(file_path)
            # NEWSTYLE gio_file = Gio.File.new_for_path(file_path)
            self.files[file_path] = gio_file
            return gio_file

    def set_synced_emblem(self, file_path):
        self._set_emblem(file_path, EMBLEM_FINISHED)

    def set_not_synced_emblem(self, file_path):
        self._set_emblem(file_path, EMBLEM_IN_PROGRESS)

    def _set_emblem(self, file_path, emblem):
        gio_file = self._get_gio_file(file_path)
        gio_file.set_attribute("metadata::emblems",
                               gio.FILE_ATTRIBUTE_TYPE_STRINGV,
                               [emblem])
        # NEWSTYLE
        # gio_file.set_attribute("metadata::emblems",
        #                        Gio.FileAttributeType.STRINGV,
        #                        [emblem],
        #                        Gio.FileQueryInfoFlags(0),
        #                        None)
        self._touch(file_path)

    def unset_emblem(self, file_path):
        gio_file = self._get_gio_file(file_path)
        gio_file.set_attribute("metadata::emblems",
                               gio.FILE_ATTRIBUTE_TYPE_STRINGV,
                               [])
        # NEWSTYLE
        # gio_file.set_attribute("metadata::emblems",
        #                        Gio.FileAttributeType.STRINGV,
        #                        [],
        #                        Gio.FileQueryInfoFlags(0),
        #                        None)

        del self.files[file_path]
        self._touch(file_path)

    def remove_all(self):
        for path in self.files.keys():
            self.unset_emblem(path)
