# -*- coding: utf-8 -*-

import os
from subprocess import call

from .win32_utils import is_handler_registered

# The space in the keys is added on purpose, it adds priority in front of
# handlers registered by other applications.
# The windows explorer sorts alphabetically the handlers, then only keeps the
# 11 firsts.
CHILD_KEY_SYNCED = r' bajoo.overlay.synced'
CHILD_KEY_NOT_SYNCED = r' bajoo.overlay.notsynced'
CHILD_KEYS = [CHILD_KEY_SYNCED, CHILD_KEY_NOT_SYNCED]


def is_installed():
    for key in CHILD_KEYS:
        if not is_handler_registered(key):
            return False
    return True


def _get_script_path():
    path = os.path.realpath(__file__)
    path = os.path.dirname(path)
    path = os.path.join(path, 'win32_com_server.py')
    return path


def install_com_server():
    """
        why using subprocess.call? because the server registration needs
        administrator credentials, and during the elevation procedure,
        the whole application (not only the process) is started a second
        time with the admin right.  It does not work with
        multiprocessing.process.
    """

    call(['python', _get_script_path()])


def uninstall_com_server():
    """
        see the description of install_com_server.
    """

    call(['python', _get_script_path(), '--unregister'])
