# -*- coding: utf-8 -*-

from multiprocessing.connection import Listener
import os
import stat
from threading import Thread

from ..abstract_emblem import AbstractEmblemManagement


class Win32ComOverlayHandlerServer(AbstractEmblemManagement):
    def __init__(self):
        AbstractEmblemManagement.__init__(self)
        self.files = {}
        self._server_running = True
        self._listener = Listener(r'\\.\pipe\bajoo.overlay.pipe')
        self._t = Thread(target=self._listener_for_handlers)
        self._t.daemon = True
        self._t.start()

    def _at_exit(self):
        self._server_running = False

        try:
            self._listener.close()
        except:
            pass

        self._listener = None
        self.removeAll()

    def _touch(self, path):
        file_att = os.stat(path)[0]

        if file_att & stat.S_IWRITE:
            os.chmod(path, stat.S_IREAD)
            os.chmod(path, stat.S_IWRITE)
        else:
            os.chmod(path, stat.S_IWRITE)
            os.chmod(path, stat.S_IREAD)

    def _listener_for_handlers(self):
        while self._server_running:
            try:
                con = self._listener.accept()
                self._serve_request(con)
            except:
                self._server_running = False
                self._listener and self._listener.close()

    def _serve_request(self, con):
        try:
            path, handler_type = con.recv()
            result = self._overlay_this_path(path, handler_type)
            con.send(result)
        except:
            pass
        finally:
            con and con.close()

    def _overlay_this_path(self, path, icon_type):
        icon = self.files.get(path)
        if icon_type == icon:
            return True

        return False

    def set_synced_emblem(self, file_path):
        self.files[file_path] = 'synced'
        self._touch(file_path)

    def set_not_synced_emblem(self, file_path):
        self.files[file_path] = 'not_synced'
        self._touch(file_path)

    def unset_emblem(self, file_path):
        del self.files[file_path]
        self._touch(file_path)

    def remove_all(self):
        for path in self.files.keys():
            self.unset_emblem(path)
