import wx

from ....common.i18n import N_
from ...base_wx_view import BaseWxView
from ...dynamic_text import DynamicText
from ...traits.wx_window_trait import WxWindowTrait
from .account_deletion_window_base_view import AccountDeletionWindowBaseView


class AccountDeletionWindowWxView(WxWindowTrait, AccountDeletionWindowBaseView,
                                  BaseWxView, wx.Dialog):

    ID_DESTROY_VIEW = wx.NewId()

    def __init__(self, **kwargs):
        super(AccountDeletionWindowWxView, self).__init__(
            style=wx.DEFAULT_DIALOG_STYLE | wx.RESIZE_BORDER | wx.MAXIMIZE_BOX,
            **kwargs)

        self._error_text = DynamicText(self)
        self._error_text.Hide()
        self._error_text.SetForegroundColour('red')
        explanation_text = wx.StaticText(self)
        password_label = DynamicText(self)
        password_input = wx.TextCtrl(
            self, wx.ID_ANY,
            style=wx.TE_PASSWORD,
            name='password')

        btn_cancel = wx.Button(self, wx.ID_CANCEL)
        btn_create = wx.Button(self, wx.ID_OK)

        buttons_sizer = wx.StdDialogButtonSizer()
        buttons_sizer.SetAffirmativeButton(btn_create)
        buttons_sizer.SetCancelButton(btn_cancel)
        buttons_sizer.Realize()

        main_sizer = self.make_sizer(wx.VERTICAL, [
            self._error_text,
            explanation_text,
            None,
            self.make_sizer(wx.HORIZONTAL, [password_label, password_input],
                            outside_border=False, proportion=1),
            None,
            buttons_sizer])
        self.SetSizer(main_sizer)

        self.register_many_i18n('SetLabel', {
            btn_create: N_('Confirmer'),
            btn_cancel: N_('Cancel'),
            password_label: N_('Password:')
        })
        self.register_many_i18n('SetLabelMarkup', {
            explanation_text: N_(
                "You are about to delete your account. If you confirm, all "
                "your data will be erased.\n"
                "<b>This operation is irreversible!</b>\n\n"
                "You must confirm by typing your password."
            )
        })

        explanation_text.Wrap(self.GetClientSize().width - 15)

        self.Bind(wx.EVT_CLOSE, self._on_cancel)
        self.Bind(wx.EVT_BUTTON, self._on_cancel, id=wx.ID_CANCEL)
        self.Bind(wx.EVT_BUTTON, self._on_confirmation, id=wx.ID_OK)

    @BaseWxView.public_method
    def show_modal(self):
        """Show the Windows, and block until window is closed.

        Note: this call is blocking.
        """
        # Note: the window (or its parent) can be destroyed during the
        # ShowModal(). This will produce wx warnings in logs.
        result = self.ShowModal()

        # if self is False, the C++ part is already destroyed.
        if self and result is self.ID_DESTROY_VIEW:
            self.Destroy()

    @BaseWxView.public_method
    def destroy(self):
        if self.IsModal():
            self.EndModal(self.ID_DESTROY_VIEW)
            # NOTE: We can't destroy the window here: we are still in the
            # EventLoop created by ShowModal() (and so, inside the ShowModal()
            # call)
        else:
            self.Destroy()

    def _on_cancel(self, _event):
        self.send_cancel_action()

    def _on_confirmation(self, _event):
        self._error_text.Hide()
        password = self.FindWindow('password').GetValue()
        self.delete_account_action(password)

    @BaseWxView.public_method
    def show_error(self, error):
        self._error_text.Show()
        self.Layout()
        self._error_text.SetLabel(error)

    @BaseWxView.public_method
    def enable(self):
        self.FindWindowById(wx.ID_CANCEL).Enable()
        self.FindWindowById(wx.ID_OK).Enable()

    @BaseWxView.public_method
    def disable(self):
        self.FindWindowById(wx.ID_CANCEL).Disable()
        self.FindWindowById(wx.ID_OK).Disable()
