
import wx

from ....common.i18n import N_
from ...base_wx_view import BaseWxView
from ...form.change_password_form import ChangePasswordForm
from ...traits.wx_window_trait import WxWindowTrait
from .change_password_window_base_view import ChangePasswordWindowBaseView


class ChangePasswordWindowWxView(ChangePasswordWindowBaseView, WxWindowTrait,
                                 BaseWxView, wx.Dialog):

    ID_DESTROY_VIEW = wx.NewId()

    def __init__(self, **kwargs):
        super(ChangePasswordWindowWxView, self).__init__(
            style=wx.DEFAULT_DIALOG_STYLE | wx.RESIZE_BORDER | wx.MAXIMIZE_BOX,
            **kwargs)

        self.register_i18n(self, self.SetTitle, N_('Bajoo - Change password'))
        self.form = ChangePasswordForm(self)

        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.form, 0, wx.EXPAND)
        self.SetSizer(sizer)
        self.form.GetSizer().SetSizeHints(self)

        self.Bind(ChangePasswordForm.EVT_SUBMIT, self._on_submit)
        self.Bind(wx.EVT_CLOSE, self._on_cancel)
        self.Bind(wx.EVT_BUTTON, self._on_cancel, id=wx.ID_CANCEL)
        self.CenterOnScreen()

    @BaseWxView.public_method
    def show_modal(self):
        """Show the Windows, and block until window is closed.

        Note: this call is blocking.
        """
        result = self.ShowModal()
        if result is self.ID_DESTROY_VIEW:
            self.Destroy()

    @BaseWxView.public_method
    def destroy(self):
        if self.IsModal():
            self.EndModal(self.ID_DESTROY_VIEW)
            # NOTE: We can't destroy the window here: we are still in the
            # EventLoop created by ShowModal() (and so, inside the ShowModal()
            # call)
        else:
            self.Destroy()

    @BaseWxView.public_method
    def notify_lang_change(self):
        BaseWxView.notify_lang_change(self)
        self.form.notify_lang_change()

    @BaseWxView.public_method
    def show_error(self, message):
        self.form.show_error(message)

    def _on_submit(self, _event):
        data = self.form.get_data()
        old_password = data[u'old_password']
        new_password = data[u'new_password']
        self.change_password_action(old_password, new_password)

    def _on_cancel(self, _event):
        self.send_cancel_action()
