
from ....common.i18n import N_
from ....common.signal import Signal

from ..base_window_controller import BaseWindowController


class PassphraseWindowController(BaseWindowController):
    """Passphrase prompt dialog

    Modal window who ask the user to enter his passphrase. It also offers the
    user to memorize his passphrase.

    The window can fire two signals: declare_passphrase when the user has
    entered a passphrase, and `request_denied` when the user deliberately
    choose to not type his passphrase.
    When one of the both signals are fired, the window will destroy itself.
    """
    def __init__(self, view, app, is_retry=False):
        BaseWindowController.__init__(self, view, app, actions={
            'submit': self._enter_passphrase_action,
            'cancel': self._send_cancel
        })

        self.declare_passphrase = Signal()
        self.request_denied = Signal()

        if is_retry:
            error_message = N_('Invalid passphrase!')
            self.view.set_error_message(error_message)

    def _send_cancel(self):
        self.request_denied.fire()
        self.destroy()

    def _enter_passphrase_action(self, passphrase, allow_save_on_disk):
        """The user has typed a passphrase.

        Args:
            passphrase (Text)
            allow_save_on_disk 5bool)
        """
        self.declare_passphrase.fire(passphrase, allow_save_on_disk)
        self.destroy()

    def show_modal(self):
        """Show the Windows and make it modal.

        Note: this method may block until the window is closed.
        """
        self.view.show_modal()
