
import wx
from ....common.i18n import N_, _
from ...base_wx_view import BaseWxView
from ...dynamic_text import DynamicText
from ...traits.wx_window_trait import WxWindowTrait
from .passphrase_window_base_view import PassphraseWindowBaseView


class PassphraseWindowWxView(PassphraseWindowBaseView, WxWindowTrait,
                             BaseWxView, wx.Dialog):

    ID_DESTROY_VIEW = wx.NewId()

    def __init__(self, **kwargs):
        style = wx.DEFAULT_DIALOG_STYLE | wx.STAY_ON_TOP
        super(PassphraseWindowWxView, self).__init__(parent=None,
                                                     style=style,
                                                     **kwargs)

        self.register_i18n(self, self.SetTitle,
                           N_('Bajoo - Ask for passphrase'))

        prompt = DynamicText(self, name='_prompt_txt')
        passphrase_input = wx.TextCtrl(self, style=wx.TE_PASSWORD,
                                       name='passphrase')
        allow_save_on_disk_checkbox = wx.CheckBox(self,
                                                  name='allow_save_on_disk')

        error_msg = DynamicText(self, name='error_msg')
        error_msg.SetForegroundColour(wx.RED)
        error_msg.Hide()

        ok_btn = wx.Button(self, wx.ID_OK, name='btn_ok', label=_('OK'))
        ok_btn.SetDefault()

        cancel_btn = wx.Button(self, wx.ID_CANCEL, name='btn_cancel',
                               label=_('Cancel'))

        self._set_texts()

        button_box = wx.StdDialogButtonSizer()
        button_box.SetAffirmativeButton(ok_btn)
        button_box.SetCancelButton(cancel_btn)
        button_box.Realize()

        sizer_items = [
            error_msg,
            prompt,
            passphrase_input,
            allow_save_on_disk_checkbox,
            None,
            button_box
        ]
        sizer = self.make_sizer(wx.VERTICAL, sizer_items, flag=wx.EXPAND)
        self.SetSizer(sizer)

        self.Bind(wx.EVT_CLOSE, lambda _: self.cancel_action())
        self.Bind(wx.EVT_BUTTON, lambda _: self.cancel_action(),
                  id=wx.ID_CANCEL)
        self.Bind(wx.EVT_BUTTON, self.submit, id=wx.ID_OK)

    def submit(self, _):
        self.submit_action(
            self.FindWindow('passphrase').GetValue(),
            self.FindWindow('allow_save_on_disk').GetValue())

    @BaseWxView.i18n_callback
    def _set_texts(self):
        message = _('Enter your Bajoo pasphrase to start the synchronization'
                    ' of your encrypted files.')
        prompt = self.FindWindow('_prompt_txt')
        prompt.SetLabel(message)

        checkbox = self.FindWindow('allow_save_on_disk')
        checkbox.SetLabel(_('Memorize the passphrase'))

    @BaseWxView.public_method
    def show_modal(self):
        """Show the Windows, and block until window is closed.

        Note: this call is blocking.
        """
        result = self.ShowModal()
        if result is self.ID_DESTROY_VIEW:
            self.Destroy()

    @BaseWxView.public_method
    def destroy(self):
        if self.IsModal():
            self.EndModal(self.ID_DESTROY_VIEW)
            # NOTE: We can't destroy the window here: we are still in the
            # EventLoop created by ShowModal() (and so, inside the ShowModal()
            # call)
        else:
            self.Destroy()

    @BaseWxView.public_method
    def set_error_message(self, message):
        error_msg = self.FindWindow('error_msg')
        error_msg.SetLabel(_(message))
        error_msg.Show()
        self.Layout()

    @BaseWxView.public_method
    def reset_error_message(self):
        self.FindWindow('error_msg').Hide()
