
import sys
from .promise import Promise
from .util import is_thenable


class Deferred(object):
    """

    A Deferred is the "creator" side of an async task, whereas a Promise
    represents the asynchronous value from the "consumer" side.

    Attributes:
        promise (Promise): the Promise associated to the Deferred.
        resolve (function)
        reject (function)
    """

    def __init__(self, *args, **kwargs):
        self.promise = Promise(self._executor, *args, **kwargs)

    def _executor(self, resolve, reject):
        self.resolve = resolve
        self.reject = reject

    def wrap_function(self, func, *args, **kwargs):
        """Call a function and resolve or reject the deferred from its result.

        If the function raises an exception, the deferred is rejected. If the
        function returns a Promise, the deferred will be resolved (or rejected)
        from the result of new promise.

        Args:
            func(Callable[..., T]): function to call.
            *args: arguments passed to func
            **kwargs: named arguments passed to func
        """
        try:
            r = func(*args, **kwargs)
        except:
            self.reject(*sys.exc_info())
            return

        if is_thenable(r):
            r.then(self.resolve, self.reject, True)
        else:
            self.resolve(r)
